<?php

namespace App\Dto\Output;

use ApiPlatform\Metadata\Get;
use App\Entity\NetworkSettings;
use Symfony\Component\Serializer\Annotation\Groups;

#[Get(shortName: 'NetworkSettings')]
final class NetworkSettingsOutput extends AbstractOutput
{
    #[Groups(['network-settings:read'])]
    public ?string $proxy = null;

    #[Groups(['organizational-unit:read'])]
    public ?string $dns = null;

    #[Groups(['organizational-unit:read'])]
    public ?string $netmask = null;

    #[Groups(['organizational-unit:read'])]
    public ?string $router = null;

    #[Groups(['organizational-unit:read'])]
    public ?string $ntp = null;

    #[Groups(['organizational-unit:read'])]
    public ?string $p2pMode = null;

    #[Groups(['organizational-unit:read'])]
    public ?int $p2pTime = null;

    #[Groups(['organizational-unit:read'])]
    public ?string $mcastIp = null;

    #[Groups(['organizational-unit:read'])]
    public ?int $mcastSpeed = null;

    #[Groups(['organizational-unit:read'])]
    public ?int $mcastPort = null;

    #[Groups(['organizational-unit:read'])]
    public ?string $mcastMode = null;

    #[Groups(['organizational-unit:read'])]
    public ?MenuOutput $menu = null;

    #[Groups(['organizational-unit:read'])]
    public ?HardwareProfileOutput $hardwareProfile = null;

    #[Groups(['organizational-unit:read'])]
    public ?bool $validation = null;

    #[Groups(['organizational-unit:read'])]
    public \DateTime $createdAt;

    #[Groups(['organizational-unit:read'])]
    public ?string $createdBy = null;

    public function __construct(NetworkSettings $networkSettings)
    {
        parent::__construct($networkSettings);

        $this->proxy = $networkSettings->getProxy();
        $this->dns = $networkSettings->getDns();
        $this->netmask = $networkSettings->getNetmask();
        $this->router = $networkSettings->getRouter();
        $this->ntp = $networkSettings->getNtp();
        $this->p2pMode = $networkSettings->getP2pMode();
        $this->p2pTime = $networkSettings->getP2pTime();
        $this->mcastIp = $networkSettings->getMcastIp();
        $this->mcastSpeed = $networkSettings->getMcastSpeed();
        $this->mcastPort = $networkSettings->getMcastPort();
        $this->mcastMode = $networkSettings->getMcastMode();

        if ($networkSettings->getMenu()) {
            $this->menu = new MenuOutput($networkSettings->getMenu());
        }

        if ($networkSettings->getHardwareProfile()) {
            $this->hardwareProfile = new HardwareProfileOutput($networkSettings->getHardwareProfile());
        }

        $this->validation = $networkSettings->getValidation();
        $this->createdAt = $networkSettings->getCreatedAt();
        $this->createdBy = $networkSettings->getCreatedBy();
    }
}