<?php

namespace App\Factory;

use App\Entity\HardwareType;
use App\Repository\HardwareTypeRepository;
use Zenstruck\Foundry\ModelFactory;
use Zenstruck\Foundry\Persistence\PersistentProxyObjectFactory;
use Zenstruck\Foundry\Persistence\Proxy;
use Zenstruck\Foundry\Persistence\ProxyRepositoryDecorator;

/**
 * @extends PersistentProxyObjectFactory<HardwareType>
 *
 * @method        HardwareType|Proxy                              create(array|callable $attributes = [])
 * @method static HardwareType|Proxy                              createOne(array $attributes = [])
 * @method static HardwareType|Proxy                              find(object|array|mixed $criteria)
 * @method static HardwareType|Proxy                              findOrCreate(array $attributes)
 * @method static HardwareType|Proxy                              first(string $sortedField = 'id')
 * @method static HardwareType|Proxy                              last(string $sortedField = 'id')
 * @method static HardwareType|Proxy                              random(array $attributes = [])
 * @method static HardwareType|Proxy                              randomOrCreate(array $attributes = [])
 * @method static HardwareTypeRepository|ProxyRepositoryDecorator repository()
 * @method static HardwareType[]|Proxy[]                          all()
 * @method static HardwareType[]|Proxy[]                          createMany(int $number, array|callable $attributes = [])
 * @method static HardwareType[]|Proxy[]                          createSequence(iterable|callable $sequence)
 * @method static HardwareType[]|Proxy[]                          findBy(array $attributes)
 * @method static HardwareType[]|Proxy[]                          randomRange(int $min, int $max, array $attributes = [])
 * @method static HardwareType[]|Proxy[]                          randomSet(int $number, array $attributes = [])
 */
final class HardwareTypeFactory extends ModelFactory
{
    /**
     * @see https://symfony.com/bundles/ZenstruckFoundryBundle/current/index.html#factories-as-services
     *
     * @todo inject services if required
     */
    public function __construct()
    {
        parent::__construct();
    }

    public static function class(): string
    {
        return HardwareType::class;
    }

    /**
     * @see https://symfony.com/bundles/ZenstruckFoundryBundle/current/index.html#model-factories
     *
     * @todo add your default values here
     */
    protected function getDefaults(): array
    {
        return [
            'createdAt' => self::faker()->dateTime(),
            'name' => self::faker()->text(255),
            'updatedAt' => self::faker()->dateTime(),
        ];
    }

    /**
     * @see https://symfony.com/bundles/ZenstruckFoundryBundle/current/index.html#initialization
     */
    protected function initialize(): self
    {
        return $this
            // ->afterInstantiate(function(HardwareType $hardwareType): void {})
        ;
    }

    protected static function getClass(): string
    {
        return HardwareType::class;
    }
}
